exceptiontools.MissingPitchError
================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError

.. autoclass:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__delattr__
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getitem__
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getslice__
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__repr__
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setattr__
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setstate__
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__str__
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__unicode__

Bases
-----

- :py:class:`exceptions.Exception <exceptions.Exception>`

- :py:class:`exceptions.BaseException <exceptions.BaseException>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingPitchError.MissingPitchError.__unicode__
   :noindex:
